![example workflow](https://github.com/harvey251/pydantic-lambda-handler/actions/workflows/main.yml/badge.svg) [![codecov](https://codecov.io/gh/harvey251/pydantic-lambda-handler/branch/main/graph/badge.svg?token=PX0GRFCYQE)](https://codecov.io/gh/harvey251/pydantic-lambda-handler) ![pypi package](https://img.shields.io/pypi/v/pydantic-lambda-handler?color=%2334D058&label=pypi%20package)

# Vision

Aim to create an easy-to-use decorator on a lambda for quick development of apis on AWS lambda using AWS Gateway.

Inspired by, and attempting to match the [Fast API](https://fastapi.tiangolo.com) api.

Currently, I'm working through the first steps to hit the basics.

This is very much at the beginning of the project, so I could do with all the help I can get :D

## MUST HAVE
* creates open api schema

API Gateway Lambda proxy integration
https://docs.aws.amazon.com/apigateway/latest/developerguide/set-up-lambda-proxy-integrations.html#api-gateway-simple-proxy-for-lambda-input-format

https://docs.aws.amazon.com/lambda/latest/dg/services-apigateway-tutorial.html

```commandline
pip install --target ./demo_app ../.
```
